@@ -1,13 +1,15 @@
-# $Id: Job.pm,v 1.13 2002/09/30 21:04:43 joern Exp $
+# $Id: Job.pm,v 1.17 2004/04/11 23:36:19 joern Exp $
 
 #-----------------------------------------------------------------------
-# Copyright (C) 2001-2002 Jrn Reder <joern@zyn.de> All Rights Reserved
+# Copyright (C) 2001-2003 Jrn Reder <joern AT zyn.de>.
+# All Rights Reserved. See file COPYRIGHT for details.
 # 
 # This program is part of Video::DVDRip, which is free software; you can
 # redistribute it and/or modify it under the same terms as Perl itself.
 #-----------------------------------------------------------------------
 
 package Video::DVDRip::Cluster::Job;
+use Locale::TextDomain qw (video.dvdrip);
 
 use base Video::DVDRip::Job;
 
@@ -53,6 +55,7 @@ sub log {
 	my $self = shift; $self->trace_in;
 	my ($msg) = @_;
 
+	$msg =~ s/\n$//;
 	$msg .= " on node ".$self->node->name;
 	
 	return $self->SUPER::log ($msg);
