@@ -1,4 +1,4 @@
-# $Id: Config.pm,v 1.44 2004/04/11 23:36:19 joern Exp $
+# $Id: Config.pm,v 1.48 2005/05/16 11:22:25 joern Exp $
 
 #-----------------------------------------------------------------------
 # Copyright (C) 2001-2003 Jrn Reder <joern AT zyn.de>.
@@ -32,6 +32,9 @@ sub set_presets			{ shift->{presets}		= $_[1] }
 sub set_filename		{ shift->{filename}		= $_[1] }
 sub set_last_saved_data		{ shift->{last_saved_data}	= $_[1] }
 
+my @BPP = '<none>';
+for ( my $b = 1.0; $b > 0 && push @BPP, sprintf("%.2f",$b); $b -= 0.05 ) {};
+
 my %CONFIG_PARAMETER = (
 	program_name => {
 		type  => 'string',
@@ -74,10 +77,10 @@ my %CONFIG_PARAMETER = (
 	play_dvd_command => {
 		label => __"DVD player command",
 		type  => 'string',
-		value => 'mplayer <dvd://%t -aid %(%a+%b) -chapter %c -dvdangle %m>',
+		value => 'mplayer <dvd://%t -aid %(%a+%b) -chapter %c -dvdangle %m -dvd-device %d>',
 		presets => [
-			'mplayer <dvd://%t -aid %(%a+%b) -chapter %c -dvdangle %m>',
-			'xine -a %a -p <dvd://%t.%c>',
+			'mplayer <dvd://%t -aid %(%a+%b) -chapter %c -dvdangle %m -dvd-device %d>',
+			'xine -a %a -p <dvd://%d/%t.%c>',
 		],
 	},
 	play_file_command => {
@@ -162,6 +165,14 @@ my %CONFIG_PARAMETER = (
 		value => 'avi',
 		presets => [ "avi", "ogg", "mpeg" ],
 	},
+	default_bpp => {
+		label => __"Default BPP value",
+		type  => 'number',
+		value => '<none>',
+		presets => \@BPP,
+		tooltip => __"If this option is set dvd::rip automatically ".
+		             "calculates the video bitrate using this BPP value",
+	},
 	burn_cdrecord_device => {
 		label => __"cdrecord device (n,n,n or filename)",
 		type  => 'string',
@@ -191,6 +202,7 @@ my %CONFIG_PARAMETER = (
 		presets => [
 			'/usr/lib/xcdroast-0.98/bin/xcdrwrap CDRECORD',
 			'cdrecord',
+			'dvdrecord',
 		],
 	},
 	burn_mkisofs_cmd => {
@@ -244,14 +256,6 @@ my %CONFIG_PARAMETER = (
 		presets => [
 			'all - blank the entire disk',
 			'fast - minimally blank the entire disk',
-#			'unclose - unclose last session',
-#			'session - blank last session',
-#			'disc - blank the entire disk',
-#			'disk - blank the entire disk',
-#			'minimal - minimally blank the entire disk',
-#			'track - blank a track',
-#			'unreserve - unreserve a track',
-#			'trtail - blank a track tail',
 		],
 	},
 
@@ -299,6 +303,11 @@ my %CONFIG_PARAMETER = (
 			"za - Zhuang", "zh - Chinese", "zu - Zulu",
 		],
 	},
+	workaround_nptl_bugs => {
+		label	=> __"Workaround transcode NPTL bugs",
+		type	=> 'switch',
+		value	=> 1,
+	},
 );
 
 my @CONFIG_ORDER = (
@@ -328,8 +337,10 @@ my @CONFIG_ORDER = (
 	)],
 	__"Miscellaneous options" => [qw(
 		default_video_codec  default_container
+		default_bpp
 		main_window_width    main_window_height
 		preferred_lang       show_tooltips
+		workaround_nptl_bugs
 	)],
 );
 
@@ -602,6 +613,18 @@ sub new {
 	return bless $self, $type;
 }
 
+sub init_nptl_bug_workaround {
+	my $self = shift;
+	
+	if ( $self->get_value("workaround_nptl_bugs") ) {
+		$ENV{LD_ASSUME_KERNEL} = "2.2.5";
+	} else {
+		delete $ENV{LD_ASSUME_KERNEL};
+	}
+	
+	1;
+}
+
 sub load {
 	my $self = shift;
 	
@@ -632,6 +655,8 @@ sub load {
 		}
 	}
 	
+	$self->init_nptl_bug_workaround;
+	
 	1;
 }
 
@@ -661,7 +686,7 @@ sub save {
 	my $fh = FileHandle->new;
 
 	open ($fh, "> $filename") or die "can't write $filename";
-	print $fh q{# $Id: Config.pm,v 1.44 2004/04/11 23:36:19 joern Exp $},"\n";
+	print $fh q{# $Id: Config.pm,v 1.48 2005/05/16 11:22:25 joern Exp $},"\n";
 	print $fh "# This file was generated by Video::DVDRip Version $Video::DVDRip::VERSION\n\n";
 
 	print $fh ${$data_sref};
@@ -669,6 +694,8 @@ sub save {
 	
 	$self->set_last_saved_data ($data_sref);
 
+	$self->init_nptl_bug_workaround;
+
 	1;
 }
 
